---
feature_story: FS_26_43_73_72
feature_title: func tree
feature_status: TEST
---

This feature:
*   Loads function `data_envelope`-s automatically by querying delegators (`DelegatorAbstract`).
*   Places each function on a tree to auto-complete args to select it.
*   The args to select a function can be specified out of order.

This feature is similar to interp tree (FS_01_89_09_24), but not quite:

*   FS_01_89_09_24 interp tree does not select function, it selects next interp (`AbstractInterpFactory`).

*   FS_01_89_09_24 interp tree requires args to specify tree path in order.
    
    Unlike func tree which tries to consume args out of order (standard `argrelay` search).


